==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/RowSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { RowSeparatorDescription } from "./RowSeparatorDescription";
/**
 * @hidden
 */
var RowSeparatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(RowSeparatorDescriptionMetadata, _super);
    function RowSeparatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RowSeparatorDescriptionMetadata.b = function (a) {
        if (RowSeparatorDescriptionMetadata.a == null) {
            RowSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RowSeparatorDescriptionMetadata.c(RowSeparatorDescriptionMetadata.a);
        }
        if (a.k(RowSeparatorDescriptionMetadata.a)) {
            return;
        }
        a.aa(RowSeparatorDescriptionMetadata.a);
    };
    RowSeparatorDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    RowSeparatorDescriptionMetadata.d = function (a) {
        RowSeparatorDescriptionMetadata.b(a);
        a.ac("RowSeparator", function () { return new RowSeparatorDescription(); });
        a.ab("RowSeparator", RowSeparatorDescriptionMetadata.a);
    };
    RowSeparatorDescriptionMetadata.$t = markType(RowSeparatorDescriptionMetadata, 'RowSeparatorDescriptionMetadata');
    RowSeparatorDescriptionMetadata.a = null;
    return RowSeparatorDescriptionMetadata;
}(Base));
export { RowSeparatorDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/RowSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { RowSeparatorDescription } from "./RowSeparatorDescription";
/**
 * @hidden
 */
var RowSeparatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RowSeparatorDescriptionMetadata, _super);
    function RowSeparatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RowSeparatorDescriptionMetadata.b = function (a) {
        if (RowSeparatorDescriptionMetadata.a == null) {
            RowSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RowSeparatorDescriptionMetadata.c(RowSeparatorDescriptionMetadata.a);
        }
        if (a.k(RowSeparatorDescriptionMetadata.a)) {
            return;
        }
        a.ac(RowSeparatorDescriptionMetadata.a);
    };
    RowSeparatorDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    RowSeparatorDescriptionMetadata.d = function (a) {
        RowSeparatorDescriptionMetadata.b(a);
        a.ae("RowSeparator", function () { return new RowSeparatorDescription(); });
        a.ad("RowSeparator", RowSeparatorDescriptionMetadata.a);
    };
    RowSeparatorDescriptionMetadata.$t = markType(RowSeparatorDescriptionMetadata, 'RowSeparatorDescriptionMetadata');
    RowSeparatorDescriptionMetadata.a = null;
    return RowSeparatorDescriptionMetadata;
}(Base));
export { RowSeparatorDescriptionMetadata };
